Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(135)

Unified Diff: src/crankshaft/ia32/lithium-codegen-ia32.cc

Issue 1409123003: [runtime] Avoid @@isConcatSpreadable lookup for fast path Array.prototype.concat (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: simplifications Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: src/crankshaft/ia32/lithium-codegen-ia32.cc
diff --git a/src/crankshaft/ia32/lithium-codegen-ia32.cc b/src/crankshaft/ia32/lithium-codegen-ia32.cc
index ee8317f2d55f38f24d98a3ef53f5fba8d60af3de..7fa3f4bd9c4bf89faa1c90ac74c3a9a87db9e3b5 100644
--- a/src/crankshaft/ia32/lithium-codegen-ia32.cc
+++ b/src/crankshaft/ia32/lithium-codegen-ia32.cc
@@ -3045,11 +3045,12 @@ void LCodeGen::DoLoadKeyedFixedArray(LLoadKeyed* instr) {
__ j(not_equal, &done);
if (info()->IsStub()) {
// A stub can safely convert the hole to undefined only if the array
// protector cell contains (Smi) Isolate::kArrayProtectorValid. Otherwise
// it needs to bail out.
- __ mov(result, isolate()->factory()->array_protector());
+ __ LoadRoot(result, Heap::kArrayElementsProtectorRootIndex);
__ cmp(FieldOperand(result, PropertyCell::kValueOffset),
- Immediate(Smi::FromInt(Isolate::kArrayProtectorValid)));
+ Immediate(Smi::FromInt(Isolate::kArrayElementsProtectorValid)));
DeoptimizeIf(not_equal, instr, Deoptimizer::kHole);
}
__ mov(result, isolate()->factory()->undefined_value());
@@ -3045,11 +3045,12 @@ void LCodeGen::DoLoadKeyedFixedArray(LLoadKeyed* instr) {
if (info()->IsStub()) {
// A stub can safely convert the hole to undefined only if the array
- // protector cell contains (Smi) Isolate::kArrayProtectorValid. Otherwise
+ // protector cell contains (Smi) Isolate::kArrayElementsProtectorValid.
+ // Otherwise
// it needs to bail out.

Powered by Google App Engine
This is Rietveld 408576698